@@ -1,4 +1,4 @@
-# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of logilab-database.
@@ -317,7 +317,7 @@ class DBAPIAdapter(object):
                 return unicode(value, encoding, 'replace')
         elif typecode == self.BOOLEAN:
             return bool(value)
-        elif typecode == self.BINARY and not binarywrap is None:
+        elif typecode == self.BINARY and binarywrap is not None:
             return binarywrap(value)
         elif typecode == self.UNKNOWN:
             # may occurs on constant selection for instance (e.g. SELECT 'hop')
@@ -511,6 +511,19 @@ def register_function(funcdef):
     """register the function `funcdef` on supported backends"""
     SQL_FUNCTIONS_REGISTRY.register_function(funcdef)
 
+class _TypeMapping(dict):
+    def __getitem__(self, key):
+        try:
+            return dict.__getitem__(self, key)
+        except KeyError:
+            if key == 'TZDatetime':
+                return self['Datetime']
+            if key == 'TZTime':
+                return self['Time']
+            raise
+
+    def copy(self):
+        return _TypeMapping(dict.copy(self))
 
 class _GenericAdvFuncHelper(FTIndexerMixIn):
     """Generic helper, trying to provide generic way to implement
@@ -520,8 +533,11 @@ class _GenericAdvFuncHelper(FTIndexerMixIn):
     """
     # 'canonical' types are `yams` types. This dictionnary map those types to
     # backend specific types
-    TYPE_MAPPING = {
+    TYPE_MAPPING = _TypeMapping({
         'String' :   'text',
+        'SizeConstrainedString': 'varchar(%s)',
+        'Password' : 'bytea',
+        'Bytes' :    'bytea',
         'Int' :      'integer',
         'Float' :    'float',
         'Decimal' :  'decimal',
@@ -530,10 +546,7 @@ class _GenericAdvFuncHelper(FTIndexerMixIn):
         'Time' :     'time',
         'Datetime' : 'timestamp',
         'Interval' : 'interval',
-        'Password' : 'bytea',
-        'Bytes' :    'bytea',
-        'SizeConstrainedString': 'varchar(%s)',
-        }
+        })
 
     # DBMS resources descriptors and accessors
     backend_name = None # overridden in subclasses ('postgres', 'sqlite', etc.)
@@ -687,6 +700,38 @@ INSERT INTO %s VALUES (0);''' % (seq_name, seq_name)
         return ('UPDATE %s SET last=last+1;' % seq_name,
                 'SELECT last FROM %s;' % seq_name)
 
+    def sql_add_limit_offset(self, sql, limit=None, offset=0, orderby=None):
+        """
+        modify the sql statement to add LIMIT and OFFSET clauses
+        (or to emulate them if the backend does not support these SQL extensions)
+
+        `orderby` argument may be needed for some backend (e.g. sqlserver)
+        """
+        if limit is None and not offset:
+            return sql
+        sql = [sql]
+        if limit is not None:
+            sql.append('LIMIT %d' % limit)
+        if offset is not None and offset > 0:
+            sql.append('OFFSET %d' % offset)
+        return '\n'.join(sql)
+
+    def sql_add_order_by(self, sql, sortterms, selection, needwrap, has_limit_or_offset):
+        """
+        add an ORDER BY clause to the SQL query, and wrap the query if necessary
+        :sql: the original sql query
+        :sortterms: a list of term with sorting order, as strings
+        :selection: the selection that must be gathered after ORDER BY
+        :needwrap: boolean, True if the query must be wrapped in a subquery
+        :has_limit_or_offset: not used (sqlserver helper needs this)
+        """
+        sql += '\nORDER BY %s' % ','.join(sortterms)
+        if sortterms and needwrap:
+            selection = ['T1.C%s' % i for i in xrange(len(selection))]
+            sql = 'SELECT %s FROM (%s) AS T1' % (','.join(selection), sql)
+        return sql
+
+
     def sql_rename_col(self, table, column, newname, coltype, null_allowed):
         return 'ALTER TABLE %s RENAME COLUMN %s TO %s' % (
             table, column, newname)
