@@ -34,7 +34,7 @@ def _tokenize(string):
 class TokenizeTC(unittest.TestCase):
 
     def test_utf8(self):
-        self.assertEquals(_tokenize(u'n2'),
+        self.assertEqual(_tokenize(u'n2'),
                           ['n2'])
 
 
@@ -55,7 +55,7 @@ class IndexerTC(unittest.TestCase):
 
     def test_index_object(self):
         self.indexer.index_object(1, IndexableObject())
-        self.assertListEquals(self.cnx.received,
+        self.assertListEqual(self.cnx.received,
                           [('SELECT word_id FROM word WHERE word=%(word)s;', {'word': 'ginco'}),
                            ('INSERT INTO appears(uid, word_id, pos) VALUES (%(uid)s,%(wid)s,%(position)s);', {'position': 0, 'wid': 1, 'uid': 1}),
                            ('SELECT word_id FROM word WHERE word=%(word)s;', {'word': 'jpl'}),
@@ -73,14 +73,14 @@ class IndexerTC(unittest.TestCase):
 
     def test_fulltext_search(self):
         list(self.indexer.fulltext_search(u'ginco'))
-        self.assertEquals(self.cnx.received,
+        self.assertEqual(self.cnx.received,
                           [('SELECT count(*) as rating, appears0.uid FROM appears as appears0, word as word0 WHERE word0.word = %(word0)s  AND word0.word_id = appears0.word_id  GROUP BY appears0.uid ;',
                             {'word0': 'ginco'})
                            ])
 
     def test_fulltext_search2(self):
         list(self.indexer.fulltext_search(u'ginco-jpl'))
-        self.assertEquals(self.cnx.received,
+        self.assertEqual(self.cnx.received,
                           [('SELECT count(*) as rating, appears0.uid FROM appears as appears0, word as word0, appears as appears1, word as word1 WHERE word0.word = %(word0)s  AND word0.word_id = appears0.word_id  AND word1.word = %(word1)s  AND word1.word_id = appears1.word_id  AND appears0.uid = appears1.uid  GROUP BY appears0.uid ;',
                             {'word1': 'jpl', 'word0': 'ginco'})
                            ])
@@ -91,7 +91,7 @@ class GetSchemaTC(unittest.TestCase):
     def test(self):
         indexer = FTIndexerMixIn()
         indexer.sql_create_sequence = lambda x: 'CREATE SEQUENCE %s;' % x
-        self.assertEquals(indexer.sql_init_fti(),
+        self.assertEqual(indexer.sql_init_fti(),
                           '''
 CREATE SEQUENCE word_id_seq;
 
